@@ -10,6 +10,6 @@ urlpatterns = patterns('',
     (r'^jsi18n/$','autoforms.views.jsi18n'),
 	(r'^preview/$','autoforms.views.preview'),
 	(r'^preview/(?P<id>\d+)/$','autoforms.views.preview'),
-	(r'^fill/(?P<id>\d+)/$','autoforms.views.fill'),
+	url(r'^fill/(?P<id>\d+)/$','autoforms.views.fill',name="form-fill"),
 	(r'^overview/(?P<id>\d+)/$','autoforms.views.overview'),
 )
